/*
 * credits_screen.cpp
 *
 * This file is part of Knights.
 *
 * Copyright (C) Stephen Thompson, 2006 - 2009.
 * Copyright (C) Kalle Marjola, 1994.
 *
 * Knights is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Knights is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Knights.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "misc.hpp"

#include "credits_screen.hpp"
#include "gui_text_wrap.hpp"
#include "knights_app.hpp"
#include "rstream.hpp"
#include "title_screen.hpp"

// coercri
#include "gcn/cg_font.hpp"

#include "guichan.hpp"

#include "boost/scoped_ptr.hpp"
using namespace boost;

class CreditsScreenImpl : public gcn::ActionListener, public gcn::WidgetListener {
public:
    explicit CreditsScreenImpl(KnightsApp &kg, gcn::Gui &gui);
    void action(const gcn::ActionEvent &event);
    void widgetResized(const gcn::Event &event);
    
private:
    KnightsApp &knights_app;
    scoped_ptr<GuiTextWrap> text_wrap;
    scoped_ptr<gcn::ScrollArea> scroll_area;
};

CreditsScreenImpl::CreditsScreenImpl(KnightsApp &app, gcn::Gui &gui)
    : knights_app(app)
{
    RStream str("credits.txt");
    std::string credits;
    while (str) {
        char c = 0;
        str.get(c);
        credits += c;
    }
    
    text_wrap.reset(new GuiTextWrap);
    text_wrap->setForegroundColor(gcn::Color(255,255,255));
    text_wrap->setRich(true);
    text_wrap->setText(credits);
    text_wrap->addActionListener(this);
    
    scroll_area.reset(new gcn::ScrollArea);
    scroll_area->setContent(text_wrap.get());
    scroll_area->addWidgetListener(this);
    scroll_area->setBackgroundColor(gcn::Color(0,0,0));
    scroll_area->setOpaque(true);
    scroll_area->setScrollbarWidth(16);
    gui.setTop(scroll_area.get());
}

void CreditsScreenImpl::action(const gcn::ActionEvent &event)
{
    auto_ptr<Screen> scr(new TitleScreen);
    knights_app.requestScreenChange(scr);
}

void CreditsScreenImpl::widgetResized(const gcn::Event &event)
{
    text_wrap->setWidth(std::max(0, scroll_area->getWidth() - scroll_area->getScrollbarWidth()));
    text_wrap->adjustHeight();
    scroll_area->logic();
}

bool CreditsScreen::start(KnightsApp &knights_app, shared_ptr<Coercri::Window> w, gcn::Gui &gui)
{
    pimpl.reset(new CreditsScreenImpl(knights_app, gui));
    return true;
}
