/*
 * config_map.cpp
 *
 * This file is part of Knights.
 *
 * Copyright (C) Stephen Thompson, 2006 - 2009.
 * Copyright (C) Kalle Marjola, 1994.
 *
 * Knights is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Knights is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Knights.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "misc.hpp"

#include "config_map.hpp"
#include "kfile.hpp"

void PopConfigMap(KConfig::KFile &kf, ConfigMap &cmap)
{
    const KConfig::Value * tbl = kf.getTop();

    try {
        if (tbl) {
            string key = "";
            while (1) {
                key = tbl->getTableNext(key);
                if (key.empty()) break;   // reached the end
                const KConfig::Value &val = tbl->getTable(key);

                if (val.isInt()) {
                    cmap.setInt(key, val.getInt());
                } else if (val.isString()) {
                    cmap.setString(key, val.getString());
                } else {
                    kf.error("incorrect data type in config table");
                }
            }
        }
    } catch (...) {
        kf.pop();
        throw;
    }
    kf.pop();
}
